typedef enum tcurses_FMT_e {
	FMT_RESET,
	FMT_CLEAR,
	FMT_HOME,
	FMT_GOTOXY,
	FMT_GETXY_REQ,
	FMT_GETXY_RESP,
	FMT_INCX,
	FMT_SETFG,
	FMT_SETBG,
	FMT_SETA,
	FMT_SETATTR,
	FMT_QUERY_XY,
	FMT_QUERY_STATUS,
	FMT_num_fmts
} tcurses_FMT_t;

typedef struct tcurses_drv_color_s tcurses_drv_color_t;

struct tcurses_drv_color_s {
	char r, g, b;
	char code;
	char attr_mask;
	char *name;
	tcurses_drv_color_t *next;
};

typedef enum tcurses_drv_qry_e {
	CH_IDLE,
	CH_GOTXY,
	CH_STATUS
} tcurses_drv_qry_t;


typedef struct tcurses_drv_s {
	char *fmt[FMT_num_fmts];
	int bufflen;                /* bytes required for rendering the largest format */
	int esc;
	tcurses_drv_color_t *fg_colors;
	tcurses_drv_color_t *bg_colors;


	/* query parser status */
	tcurses_drv_qry_t qry;
	int qry_status;


	/* query answers */
	int status;
	int cx, cy; /* cursor x and y coords */
} tcurses_drv_t;


tcurses_drv_t *tcurses_drv_init(const char *term_name);
void tcurses_drv_uninit(tcurses_drv_t *drv);

int tcurses_drv_reset(tcurses_drv_t *drv, char *buff);
int tcurses_drv_clear(tcurses_drv_t *drv, char *buff);
int tcurses_drv_home(tcurses_drv_t *drv, char *buff);
int tcurses_drv_gotoxy(tcurses_drv_t *drv, char *buff, int col, int row);
int tcurses_drv_incx(tcurses_drv_t *drv, char *buff, int col);

int tcurses_drv_setfg(tcurses_drv_t *drv, char *buff, char fg);
int tcurses_drv_setbg(tcurses_drv_t *drv, char *buff, char bg);
int tcurses_drv_seta(tcurses_drv_t *drv, char *buff, char a);
int tcurses_drv_setattr(tcurses_drv_t *drv, char *buff, char fg, char bg, char a);

int tcurses_drv_getch(tcurses_drv_t *drv, int ch);

/*queries */
int tcurses_drv_getxy(tcurses_drv_t *drv, char *buff);
int tcurses_drv_query_status(tcurses_drv_t *drv, char *buff);



